# fontdrasil

[![MIT/Apache 2.0](https://img.shields.io/badge/license-MIT%2FApache-blue.svg)](#license)

fontdrasil: Common types and functionality shared between all layers of fontc.

The name is a reference to Yggdrasil, the world tree.

This crate provides types that are usable at any layer of fontc. For example,
support for the three major [units](https://github.com/googlefonts/fontc/blob/main/resources/text/units.md)
used in font compilation.
